@@ -23,8 +23,8 @@ def ding_talk_alert(msg, alert_to, level='P0', keyword=None, access_token=None):
         "msgtype": "markdown",
         "markdown": {
             "title": "{}".format(keyword),
-            "text": "# 【{}】\n## 【告警级别】：{}\n## 【内容】：{}\n## 【责任人】：@{}".format(
-                keyword, level, msg, at_name)
+            "text": "{}告警：{}\n@{}".format(
+                keyword, msg, at_name)
         },
 
         "at": {
