@@ -38,26 +38,45 @@ class Postgres(object):
                 #     conf = eval(conf)
             if not conf:
                 conf = read_yaml(conf_path)
-        try:
-            self.database_postgres = psycopg2.connect(database=conf['database'],
-                                                      user=conf['user'],
-                                                      password=conf['password'],
-                                                      host=conf['host'],
-                                                      port=int(conf['port']))
+        self.conf = conf
+        # try:
+        #     self.database_postgres = psycopg2.connect(database=conf['database'],
+        #                                               user=conf['user'],
+        #                                               password=conf['password'],
+        #                                               host=conf['host'],
+        #                                               port=int(conf['port']))
 
-            self.cursor = self.database_postgres.cursor()
-        except OperationalError as e:
-            raise e
+        #     # self.cursor = self.database_postgres.cursor()
+        # except OperationalError as e:
+        #     raise e
 
     def is_table_exist(self, table_str):
         # TODO 表名字符长度限制63
         exec_str = "select exists(select * from information_schema.tables where table_name='{}');".format(
             table_str.lower()[:63])
-        self.cursor.execute(exec_str)
-        exist = self.cursor.fetchone()[0]
+        conf = self.conf
+        conn = None
+        try:
+            conn = psycopg2.connect(database=conf['database'],
+                                    user=conf['user'],
+                                    password=conf['password'],
+                                    host=conf['host'],
+                                    port=int(conf['port']))
+            cursor = conn.cursor()
+            cursor.execute(exec_str)
+            exist = cursor.fetchone()[0]
+            cursor.close()
+        except (Exception, psycopg2.DatabaseError) as error:
+            print(error)
+            conn.rollback()
+            exist = False
+        finally:
+            if conn:
+                conn.close()
         logger.info('{} is_table_exist: {}'.format(table_str, exist))
         return exist
 
+
     def upsert_df(self, df, table_name, constraint_columns,
                   date_columns=None, timestamp_columns=None
                   ):
@@ -76,6 +95,13 @@ class Postgres(object):
         :param timestamp_columns:  定义为timestamp类型的字段
         :type timestamp_columns: list of str
         """
+        conf = self.conf
+        conn = psycopg2.connect(database=conf['database'],
+                                    user=conf['user'],
+                                    password=conf['password'],
+                                    host=conf['host'],
+                                    port=int(conf['port']))
+        cursor = conn.cursor()
         data_list = df.values.tolist()
         columns = list(df.columns)
         column_list = ['"{}"'.format(c) for c in columns]
@@ -143,10 +169,12 @@ class Postgres(object):
                                         constraint_columns),
                                     exclude_columns=','.join(exclude_columns),
                                     exclude_values=','.join(exclude_values))
-            self.cursor.execute(sql_format, row)
+            cursor.execute(sql_format, row)
 
         logger.info('saved {}'.format(table_name))
-        self.database_postgres.commit()
+        conn.commit()
+        cursor.close()
+        conn.close()
 
     def update_insert_df(self, df, table_name, text_columns, constraint_columns,
                          date_columns=None, timestamp_columns=None
@@ -170,6 +198,13 @@ class Postgres(object):
         :param timestamp_columns:  定义为timestamp类型的字段
         :type timestamp_columns: list of str
         """
+        conf = self.conf
+        conn = psycopg2.connect(database=conf['database'],
+                                    user=conf['user'],
+                                    password=conf['password'],
+                                    host=conf['host'],
+                                    port=int(conf['port']))
+        cursor = conn.cursor()
         data_list = df.values.tolist()
         columns = list(df.columns)
         data_list.insert(0, columns)
@@ -213,10 +248,10 @@ class Postgres(object):
                                keys=','.join(['"{}"'.format(i)
                                              for i in constraint_columns])
                                )
-                    self.cursor.execute(
+                    cursor.execute(
                         'create table {} ({});'.format(table_name, sql_str))
-                    self.cursor.execute(add_conflict_sql)
-                    logger.info('create table: %s' %sql_str)
+                    cursor.execute(add_conflict_sql)
+                    logger.info('create table: %s' % sql_str)
             else:
                 if len(column_list) - len(constraint_columns) == 1:
                     sql = '''
@@ -294,11 +329,13 @@ class Postgres(object):
                                             exclude_columns),
                                         exclude_values=','.join(exclude_values))
 
-                self.cursor.execute(sql_format, row)
+                cursor.execute(sql_format, row)
             count += 1
 
         logger.info('saved {}'.format(table_name))
-        self.database_postgres.commit()
+        conn.commit()
+        cursor.close()
+        conn.close()
 
     def find(self, table, filter_dict=None, columns=None):
         """
@@ -312,6 +349,13 @@ class Postgres(object):
         :type columns: list of str
         :return: 查询结果
         """
+        conf = self.conf
+        conn = psycopg2.connect(database=conf['database'],
+                                    user=conf['user'],
+                                    password=conf['password'],
+                                    host=conf['host'],
+                                    port=int(conf['port']))
+        cursor = conn.cursor()
         if columns:
             columns_str = ",".join(['"{}"'.format(i) for i in columns])
         else:
@@ -328,8 +372,10 @@ class Postgres(object):
         filter_str = 'where' + ' and '.join(filter_list) if filter_list else ''
         sql = "select {} from {} {}".format(columns_str, table, filter_str)
         logger.info('sql:', sql)
-        self.cursor.execute(sql)
-        res = self.cursor.fetchall()
+        cursor.execute(sql)
+        res = cursor.fetchall()
+        cursor.close()
+        conn.close()
         return res
 
     def find_one(self, table, filter_dict, columns):
@@ -344,6 +390,13 @@ class Postgres(object):
         :type columns: list of str
         :return: 查询结果
         """
+        conf = self.conf
+        conn = psycopg2.connect(database=conf['database'],
+                                    user=conf['user'],
+                                    password=conf['password'],
+                                    host=conf['host'],
+                                    port=int(conf['port']))
+        cursor = conn.cursor()
         if columns:
             columns_str = ",".join(['"{}"'.format(i) for i in columns])
         else:
@@ -360,8 +413,10 @@ class Postgres(object):
         filter_str = 'where' + ' and '.join(filter_list) if filter_list else ''
         sql = "select {} from {} {}".format(columns_str, table, filter_str)
         logger.info('sql:', sql)
-        self.cursor.execute(sql)
-        res = self.cursor.fetchone()
+        cursor.execute(sql)
+        res = cursor.fetchone()
+        cursor.close()
+        conn.close()
         return res
 
     def find_by_sql(self, sql):
@@ -370,16 +425,19 @@ class Postgres(object):
         :param sql: 查询语句
         :return:
         """
-        self.cursor.execute(sql)
-        res = self.cursor.fetchall()
+        conf = self.conf
+        conn = psycopg2.connect(database=conf['database'],
+                                    user=conf['user'],
+                                    password=conf['password'],
+                                    host=conf['host'],
+                                    port=int(conf['port']))
+        cursor = conn.cursor()
+        cursor.execute(sql)
+        res = cursor.fetchall()
+        cursor.close()
+        conn.close()
         return res
 
-    def close_connect(self):
-        """
-        关闭数据库连接，查询、更新操作结束需要执行此操作
-        """
-        self.database_postgres.close()
-
     @staticmethod
     def _format_str(line):
         # 指定字符替换为 -
